==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ResourceNavigationLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * ResourceNavigationLink resource.
 * @property id Resource ID.
 * @property link Link to the external resource
 * @property linkedResourceType Resource type of the linked resource.
 * @property name Name of the resource that is unique within a resource group. This name can be used to access the resource.
 */
public data class ResourceNavigationLinkArgs(
    public val id: Output<String>? = null,
    public val link: Output<String>? = null,
    public val linkedResourceType: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs =
        com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .link(link?.applyValue({ args0 -> args0 }))
            .linkedResourceType(linkedResourceType?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceNavigationLinkArgs].
 */
@PulumiTagMarker
public class ResourceNavigationLinkArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var link: Output<String>? = null

    private var linkedResourceType: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("gcqorouiaywgcyxr")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("iohijpaagbeeyvtr")
    public suspend fun link(`value`: Output<String>) {
        this.link = value
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("waihbsikpjfbyimn")
    public suspend fun linkedResourceType(`value`: Output<String>) {
        this.linkedResourceType = value
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("fphnlgfnocksvajy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("vctiugjlplhifkwa")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("mmutpuhidqjmkefm")
    public suspend fun link(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.link = mapped
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("bimjickrinvdslfw")
    public suspend fun linkedResourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedResourceType = mapped
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("cecyhsnuralmohtx")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ResourceNavigationLinkArgs = ResourceNavigationLinkArgs(
        id = id,
        link = link,
        linkedResourceType = linkedResourceType,
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ResourceNavigationLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * ResourceNavigationLink resource.
 * @property id Resource ID.
 * @property link Link to the external resource
 * @property linkedResourceType Resource type of the linked resource.
 * @property name Name of the resource that is unique within a resource group. This name can be used to access the resource.
 */
public data class ResourceNavigationLinkArgs(
    public val id: Output<String>? = null,
    public val link: Output<String>? = null,
    public val linkedResourceType: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs =
        com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .link(link?.applyValue({ args0 -> args0 }))
            .linkedResourceType(linkedResourceType?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceNavigationLinkArgs].
 */
@PulumiTagMarker
public class ResourceNavigationLinkArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var link: Output<String>? = null

    private var linkedResourceType: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("psdibmawgsdlkcuo")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("vvujnrfgcoliaauk")
    public suspend fun link(`value`: Output<String>) {
        this.link = value
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("lfghlysfhdmscwxa")
    public suspend fun linkedResourceType(`value`: Output<String>) {
        this.linkedResourceType = value
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("wcdpfxwycwsaqucu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("vopxrmogsekcxehn")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("ktinhijysldytwgj")
    public suspend fun link(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.link = mapped
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("kmmbwyjmeynkawvj")
    public suspend fun linkedResourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedResourceType = mapped
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("ktgpgynnsfxambqi")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ResourceNavigationLinkArgs = ResourceNavigationLinkArgs(
        id = id,
        link = link,
        linkedResourceType = linkedResourceType,
        name = name,
    )
}
